@@ -5,12 +5,12 @@ use darling::{
 };
 use proc_macro2::{Ident, TokenStream};
 use quote::quote;
-use syn::{ext::IdentExt, DeriveInput, Error, Path};
+use syn::{ext::IdentExt, Attribute, DeriveInput, Error, Path};
 
 use crate::{
     common_args::{RenameRule, RenameRuleExt},
     error::GeneratorResult,
-    utils::get_crate_name,
+    utils::{get_crate_name, get_summary_and_description, optional_literal},
 };
 
 #[derive(FromVariant)]
@@ -27,6 +27,7 @@ struct EnumItem {
 #[darling(attributes(oai), forward_attrs(doc))]
 struct EnumArgs {
     ident: Ident,
+    attrs: Vec<Attribute>,
     data: Data<EnumItem, Ignored>,
 
     #[darling(default)]
@@ -37,6 +38,8 @@ struct EnumArgs {
     rename: Option<String>,
     #[darling(default)]
     remote: Option<Path>,
+    #[darling(default)]
+    deprecated: bool,
 }
 
 pub(crate) fn generate(args: DeriveInput) -> GeneratorResult<TokenStream> {
@@ -44,6 +47,7 @@ pub(crate) fn generate(args: DeriveInput) -> GeneratorResult<TokenStream> {
     let crate_name = get_crate_name(args.internal);
     let ident = &args.ident;
     let oai_typename = args.rename.clone().unwrap_or_else(|| ident.to_string());
+    let (title, description) = get_summary_and_description(&args.attrs)?;
     let e = match &args.data {
         Data::Enum(e) => e,
         _ => return Err(Error::new_spanned(ident, "Enum can only be applied to an enum.").into()),
@@ -111,6 +115,9 @@ pub(crate) fn generate(args: DeriveInput) -> GeneratorResult<TokenStream> {
     } else {
         None
     };
+    let title = optional_literal(&title);
+    let description = optional_literal(&description);
+    let deprecated = args.deprecated;
 
     let expanded = quote! {
         impl #crate_name::types::Type for #ident {
@@ -134,6 +141,9 @@ pub(crate) fn generate(args: DeriveInput) -> GeneratorResult<TokenStream> {
 
             fn register(registry: &mut #crate_name::registry::Registry) {
                 registry.create_schema::<Self, _>(#oai_typename, |registry| #crate_name::registry::MetaSchema {
+                    title: #title,
+                    description: #description,
+                    deprecated: #deprecated,
                     enum_items: ::std::vec![#(#enum_items),*],
                     ..#crate_name::registry::MetaSchema::new("string")
                 });
